@@ -56,38 +56,38 @@
 #'                   x3 = c(7, 8, 5, 6, 4, 2, 8, 3, 6, 1, 2, 5, 8, 6,
 #'                          2, 5, 3, 1, 6, 4, 5, 5, 3, 6, 3, 2, 2, 4))
 #'
-#' # Two-Sided 95% Confidence Interval for x1
+#' # Two-Sided 95% CI for x1
 #' ci.median(dat$x1)
 #'
-#' # One-Sided 95% Confidence Interval for x1
+#' # One-Sided 95% CI for x1
 #' ci.median(dat$x1, alternative = "less")
 #'
-#' # Two-Sided 99% Confidence Interval
+#' # Two-Sided 99% CI
 #' ci.median(dat$x1, conf.level = 0.99)
 #'
-#' # Two-Sided 95% Confidence Interval, print results with 3 digits
+#' # Two-Sided 95% CI, print results with 3 digits
 #' ci.median(dat$x1, digits = 3)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, convert value 4 to NA
+#' # Two-Sided 95% CI for x1, convert value 4 to NA
 #' ci.median(dat$x1, as.na = 4)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # listwise deletion for missing data
 #' ci.median(dat[, c("x1", "x2", "x3")], na.omit = TRUE)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately
 #' ci.median(dat[, c("x1", "x2", "x3")], group = dat$group1)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately, sort by variables
 #' ci.median(dat[, c("x1", "x2", "x3")], group = dat$group1, sort.var = TRUE)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # split analysis by group1
 #' ci.median(dat[, c("x1", "x2", "x3")], split = dat$group1)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately, split analysis by group2
 #' ci.median(dat[, c("x1", "x2", "x3")], group = dat$group1, split = dat$group2)
 ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.level = 0.95,
@@ -99,7 +99,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
   #......
   # Check if input 'x' is missing
-  if (missing(x)) {
+  if (isTRUE(missing(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -108,7 +108,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
   #......
   # Check if input 'x' is NULL
-  if (is.null(x)) {
+  if (isTRUE(is.null(x))) {
 
     stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
 
@@ -116,7 +116,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
   #......
   # Vector, matrix or data frame for the argument 'x'?
-  if (!is.atomic(x) && !is.matrix(x) && !is.data.frame(x)) {
+  if (isTRUE(!is.atomic(x) && !is.matrix(x) && !is.data.frame(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -131,14 +131,14 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # Convert user-missing values into NA
 
-  if (!is.null(as.na)) {
+  if (isTRUE(!is.null(as.na))) {
 
     # Replace user-specified values with missing values
-    x <- misty::as.na(x, as.na = as.na, check = check)
+    x <- misty::as.na(x, na = as.na, check = check)
 
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After converting user-missing values into NA, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -153,14 +153,14 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   # Non-numeric variables
   non.num <- !vapply(x, is.numeric, FUN.VALUE = logical(1L))
 
-  if (any(non.num)) {
+  if (isTRUE(any(non.num))) {
 
     x <- x[, -which(non.num), drop = FALSE]
 
     #......
     # Variables left
 
-    if (ncol(x) == 0L) {
+    if (isTRUE(ncol(x) == 0L)) {
 
       stop("No variables left for analysis after excluding non-numeric variables.", call. = FALSE)
 
@@ -174,11 +174,11 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # Listwise deletion
 
-  if (isTRUE(na.omit) && any(is.na(x))) {
+  if (isTRUE(na.omit && any(is.na(x)))) {
 
     #......
     # No group and split variable
-    if (is.null(group) && is.null(split)) {
+    if (isTRUE(is.null(group) && is.null(split))) {
 
       x <- na.omit(as.data.frame(x, stringsAsFactors = FALSE))
 
@@ -189,7 +189,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Group variable, no split variable
-    if (!is.null(group) && is.null(split)) {
+    if (isTRUE(!is.null(group) && is.null(split))) {
 
       x.group <- na.omit(data.frame(x, group = group, stringsAsFactors = FALSE))
 
@@ -203,7 +203,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # No group variable, split variable
-    if (is.null(group) && !is.null(split)) {
+    if (isTRUE(is.null(group) && !is.null(split))) {
 
       x.split <- na.omit(data.frame(x, split = split, stringsAsFactors = FALSE))
 
@@ -217,7 +217,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Group variable, split variable
-    if (!is.null(group) && !is.null(split)) {
+    if (isTRUE(!is.null(group) && !is.null(split))) {
 
       x.group.split <- na.omit(data.frame(x, group = group, split = split, stringsAsFactors = FALSE))
 
@@ -233,7 +233,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
     #......
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After listwise deletion, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -247,7 +247,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
   #......
   # Check input 'check'
-  if (!is.logical(check)) {
+  if (isTRUE(!is.logical(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -259,7 +259,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'alternative'
-    if (!all(alternative %in%  c("two.sided", "less", "greater"))) {
+    if (isTRUE(!all(alternative %in%  c("two.sided", "less", "greater")))) {
 
       stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".",
            call. = FALSE)
@@ -268,7 +268,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'conf.level'
-    if (conf.level >= 1L || conf.level <= 0L) {
+    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) {
 
       stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.",
            call. = FALSE)
@@ -277,19 +277,19 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'group'
-    if (!is.null(group)) {
+    if (isTRUE(!is.null(group))) {
 
       # Vector or factor for the argument 'group'?
-      if (!is.vector(group) && !is.factor(group)) {
+      if (isTRUE(!is.vector(group) && !is.factor(group))) {
 
         stop("Please specify a vector or factor for the argument 'group'.", call. = FALSE)
 
       }
 
       # Length of 'group' match with 'x'?
-      if (length(group) != nrow(x)) {
+      if (isTRUE(length(group) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
 
           stop("Length of the vector or factor specified in 'group' does not match the length of the vector in 'x'.",
                call. = FALSE)
@@ -304,14 +304,14 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
       }
 
       # Input 'group' completely missing
-      if (all(is.na(group))) {
+      if (isTRUE(all(is.na(group)))) {
 
         stop("The grouping variable specified in 'group' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'group'
-      if (length(na.omit(unique(group))) == 1L) {
+      if (isTRUE(length(na.omit(unique(group))) == 1L)) {
 
         warning("There is only one group represented in the grouping variable specified in 'group'.", call. = FALSE)
 
@@ -321,19 +321,19 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'split'
-    if (!is.null(split)) {
+    if (isTRUE(!is.null(split))) {
 
       # Vector or factor for the argument 'split'?
-      if (!is.atomic(split) && !is.factor(split)) {
+      if (isTRUE(!is.atomic(split) && !is.factor(split))) {
 
         stop("Please specify a vector or factor for the argument 'split'.", call. = FALSE)
 
       }
 
       # Length of 'split' doest not match with 'x'
-      if (length(split) != nrow(x)) {
+      if (isTRUE(length(split) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
 
           stop("Length of the vector or factor specified in 'split' does not match the length of the vector in 'x'.",
                call. = FALSE)
@@ -348,14 +348,14 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
       }
 
       # Input 'split' completely missing
-      if (all(is.na(split))) {
+      if (isTRUE(all(is.na(split)))) {
 
         stop("The split variable specified in 'split' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'split'
-      if (length(na.omit(unique(split))) == 1L) {
+      if (isTRUE(length(na.omit(unique(split))) == 1L)) {
 
         warning("There is only one group represented in the split variable specified in 'split'.", call. = FALSE)
 
@@ -365,7 +365,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'sort.var'
-    if (!is.logical(sort.var)) {
+    if (isTRUE(!is.logical(sort.var))) {
 
       stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE)
 
@@ -373,7 +373,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'na.omit'
-    if (!is.logical(na.omit)) {
+    if (isTRUE(!is.logical(na.omit))) {
 
       stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
 
@@ -381,7 +381,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input 'digits'
-    if (digits %% 1L != 0L || digits < 0L) {
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
 
       stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE)
 
@@ -389,7 +389,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Check input output
-    if (!is.logical(output)) {
+    if (isTRUE(!is.logical(output))) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
@@ -403,7 +403,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # Alternative hypothesis
 
-  if (all(c("two.sided", "less", "greater") %in% alternative)) {
+  if (isTRUE(all(c("two.sided", "less", "greater") %in% alternative))) {
 
     alternative <- "two.sided"
 
@@ -425,7 +425,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
 
     #......
     # Number of observations less than 6 observations
-    if (n < 6L) {
+    if (isTRUE(n < 6L)) {
 
       ci <- c(NA, NA)
 
@@ -471,7 +471,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # No Grouping, No Split
 
-  if (is.null(group) && is.null(split)) {
+  if (isTRUE(is.null(group) && is.null(split))) {
 
     result <- data.frame(variable = colnames(x),
                          n = vapply(x, function(y) length(na.omit(y)), FUN.VALUE = 1L),
@@ -489,7 +489,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # Grouping, No Split
 
-  } else if (!is.null(group) && is.null(split)) {
+  } else if (isTRUE(!is.null(group) && is.null(split))) {
 
     object.group <- lapply(split(x, f = group), function(y) misty::ci.median(y, alternative = alternative, conf.level = conf.level,
                                                                              group = NULL, split = NULL, sort.var = sort.var, na.omit = na.omit,
@@ -502,7 +502,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # No Grouping, Split
 
-  } else if (is.null(group) && !is.null(split)) {
+  } else if (isTRUE(is.null(group) && !is.null(split))) {
 
       result <- lapply(split(data.frame(x, stringsAsFactors = FALSE), f = split),
                        function(y) misty::ci.median(y, alternative = alternative, conf.level = conf.level,
@@ -512,7 +512,7 @@ ci.median <- function(x, alternative = c("two.sided", "less", "greater"), conf.l
   #----------------------------------------
   # Grouping, Split
 
-  } else if (!is.null(group) && !is.null(split)) {
+  } else if (isTRUE(!is.null(group) && !is.null(split))) {
 
     result <- lapply(split(data.frame(x, group = group, stringsAsFactors = FALSE), f = split),
                        function(y) misty::ci.median(y[, -grep("group", names(y))],
