@@ -63,41 +63,41 @@
 #'                   x3 = c(7, 8, 5, 6, 4, 2, 8, 3, 6, 1, 2, 5, 8, 6,
 #'                          2, 5, 3, 1, 6, 4, 5, 5, 3, 6, 3, 2, 2, 4))
 #'
-#' # Two-Sided 95% Confidence Interval for x1
+#' # Two-Sided 95% CI for x1
 #' ci.sd(dat$x1)
 #'
-#' # Two-Sided 95% Confidence Interval for x1 using chi square distribution
+#' # Two-Sided 95% CI for x1 using chi square distribution
 #' ci.sd(dat$x1, method = "chisq")
 #'
-#' # One-Sided 95% Confidence Interval for x1
+#' # One-Sided 95% CI for x1
 #' ci.sd(dat$x1, alternative = "less")
 #'
-#' # Two-Sided 99% Confidence Interval
+#' # Two-Sided 99% CI
 #' ci.sd(dat$x1, conf.level = 0.99)
 #'
-#' # Two-Sided 95% Confidence Interval, print results with 3 digits
+#' # Two-Sided 95% CI, print results with 3 digits
 #' ci.sd(dat$x1, digits = 3)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, convert value 4 to NA
+#' # Two-Sided 95% CI for x1, convert value 4 to NA
 #' ci.sd(dat$x1, as.na = 4)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # listwise deletion for missing data
 #' ci.sd(dat[, c("x1", "x2", "x3")], na.omit = TRUE)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately
 #' ci.sd(dat[, c("x1", "x2", "x3")], group = dat$group1)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately, sort by variables
 #' ci.sd(dat[, c("x1", "x2", "x3")], group = dat$group1, sort.var = TRUE)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # split analysis by group1
 #' ci.sd(dat[, c("x1", "x2", "x3")], split = dat$group1)
 #'
-#' # Two-Sided 95% Confidence Interval for x1, x2, and x3,
+#' # Two-Sided 95% CI for x1, x2, and x3,
 #' # analysis by group1 separately, split analysis by group2
 #' ci.sd(dat[, c("x1", "x2", "x3")],
 #'       group = dat$group1, split = dat$group2)
@@ -110,7 +110,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
   #......
   # Check if input 'x' is missing
-  if (missing(x)) {
+  if (isTRUE(missing(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -119,7 +119,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
   #......
   # Check if input 'x' is NULL
-  if (is.null(x)) {
+  if (isTRUE(is.null(x))) {
 
     stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
 
@@ -127,7 +127,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
   #......
   # Vector, matrix or data frame for the argument 'x'?
-  if (!is.atomic(x) && !is.matrix(x) && !is.data.frame(x)) {
+  if (isTRUE(!is.atomic(x) && !is.matrix(x) && !is.data.frame(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -142,14 +142,14 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Convert user-missing values into NA
 
-  if (!is.null(as.na)) {
+  if (isTRUE(!is.null(as.na))) {
 
     # Replace user-specified values with missing values
-    x <- misty::as.na(x, as.na = as.na, check = check)
+    x <- misty::as.na(x, na = as.na, check = check)
 
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After converting user-missing values into NA, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -164,14 +164,14 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   # Non-numeric variables
   non.num <- !vapply(x, is.numeric, FUN.VALUE = logical(1))
 
-  if (any(non.num)) {
+  if (isTRUE(any(non.num))) {
 
     x <- x[, -which(non.num), drop = FALSE]
 
     #......
     # Variables left
 
-    if (ncol(x) == 0L) {
+    if (isTRUE(ncol(x) == 0L)) {
 
       stop("No variables left for analysis after excluding non-numeric variables.", call. = FALSE)
 
@@ -185,11 +185,11 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Listwise deletion
 
-  if (isTRUE(na.omit) && any(is.na(x))) {
+  if (isTRUE(na.omit && any(is.na(x)))) {
 
     #......
     # No group and split variable
-    if (is.null(group) && is.null(split)) {
+    if (isTRUE(is.null(group) && is.null(split))) {
 
       x <- na.omit(as.data.frame(x, stringsAsFactors = FALSE))
 
@@ -200,7 +200,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Group variable, no split variable
-    if (!is.null(group) && is.null(split)) {
+    if (isTRUE(!is.null(group) && is.null(split))) {
 
       x.group <- na.omit(data.frame(x, group = group, stringsAsFactors = FALSE))
 
@@ -214,7 +214,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # No group variable, split variable
-    if (is.null(group) && !is.null(split)) {
+    if (isTRUE(is.null(group) && !is.null(split))) {
 
       x.split <- na.omit(data.frame(x, split = split, stringsAsFactors = FALSE))
 
@@ -228,7 +228,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Group variable, split variable
-    if (!is.null(group) && !is.null(split)) {
+    if (isTRUE(!is.null(group) && !is.null(split))) {
 
       x.group.split <- na.omit(data.frame(x, group = group, split = split, stringsAsFactors = FALSE))
 
@@ -244,7 +244,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
     #......
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After listwise deletion, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -258,7 +258,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
   #......
   # Check input 'check'
-  if (!is.logical(check)) {
+  if (isTRUE(!is.logical(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -270,7 +270,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'method'
-    if (!all(method %in%  c("chisq", "bonett"))) {
+    if (isTRUE(!all(method %in%  c("chisq", "bonett")))) {
 
       stop("Character string in the argument 'method' does not match with \"chisq\", or \"bonett\".",
            call. = FALSE)
@@ -279,7 +279,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'alternative'
-    if (!all(alternative %in%  c("two.sided", "less", "greater"))) {
+    if (isTRUE(!all(alternative %in%  c("two.sided", "less", "greater")))) {
 
       stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".",
            call. = FALSE)
@@ -288,7 +288,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'conf.level'
-    if (conf.level >= 1L || conf.level <= 0L) {
+    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) {
 
       stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.",
            call. = FALSE)
@@ -297,19 +297,19 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'group'
-    if (!is.null(group)) {
+    if (isTRUE(!is.null(group))) {
 
       # Vector or factor for the argument 'group'?
-      if (!is.vector(group) && !is.factor(group)) {
+      if (isTRUE(!is.vector(group) && !is.factor(group))) {
 
         stop("Please specify a vector or factor for the argument 'group'.", call. = FALSE)
 
       }
 
       # Length of 'group' match with 'x'?
-      if (length(group) != nrow(x)) {
+      if (isTRUE(length(group) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
 
           stop("Length of the vector or factor specified in 'group' does not match the length of the vector in 'x'.",
                call. = FALSE)
@@ -324,14 +324,14 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
       }
 
       # Input 'group' completely missing
-      if (all(is.na(group))) {
+      if (isTRUE(all(is.na(group)))) {
 
         stop("The grouping variable specified in 'group' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'group'
-      if (length(na.omit(unique(group))) == 1L) {
+      if (isTRUE(length(na.omit(unique(group))) == 1L)) {
 
         warning("There is only one group represented in the grouping variable specified in 'group'.", call. = FALSE)
 
@@ -341,19 +341,19 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'split'
-    if (!is.null(split)) {
+    if (isTRUE(!is.null(split))) {
 
       # Vector or factor for the argument 'split'?
-      if (!is.atomic(split) && !is.factor(split)) {
+      if (isTRUE(!is.atomic(split) && !is.factor(split))) {
 
         stop("Please specify a vector or factor for the argument 'split'.", call. = FALSE)
 
       }
 
       # Length of 'split' doest not match with 'x'
-      if (length(split) != nrow(x)) {
+      if (isTRUE(length(split) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
 
           stop("Length of the vector or factor specified in 'split' does not match the length of the vector in 'x'.",
                call. = FALSE)
@@ -368,14 +368,14 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
       }
 
       # Input 'split' completely missing
-      if (all(is.na(split))) {
+      if (isTRUE(all(is.na(split)))) {
 
         stop("The split variable specified in 'split' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'split'
-      if (length(na.omit(unique(split))) == 1L) {
+      if (isTRUE(length(na.omit(unique(split))) == 1L)) {
 
         warning("There is only one group represented in the split variable specified in 'split'.", call. = FALSE)
 
@@ -385,7 +385,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'sort.var'
-    if (!is.logical(sort.var)) {
+    if (isTRUE(!is.logical(sort.var))) {
 
       stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE)
 
@@ -393,7 +393,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'na.omit'
-    if (!is.logical(na.omit)) {
+    if (isTRUE(!is.logical(na.omit))) {
 
       stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
 
@@ -401,7 +401,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'digits'
-    if (digits %% 1L != 0L || digits < 0L) {
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
 
       stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE)
 
@@ -409,7 +409,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Check input 'output'
-    if (!is.logical(output)) {
+    if (isTRUE(!is.logical(output))) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
@@ -423,7 +423,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Method
 
-  if (all(c("chisq", "bonett") %in% method)) {
+  if (isTRUE(all(c("chisq", "bonett") %in% method))) {
 
     method <- "bonett"
 
@@ -432,7 +432,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Alternative hypothesis
 
-  if (all(c("two.sided", "less", "greater") %in% alternative)) {
+  if (isTRUE(all(c("two.sided", "less", "greater") %in% alternative))) {
 
     alternative <- "two.sided"
 
@@ -453,7 +453,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
     #......
     # Number of observations
-    if ((length(x) < 2L && method == "chisq") || (length(x) < 4L && method == "bonett")) {
+    if (isTRUE((length(x) < 2L && method == "chisq") || (length(x) < 4L && method == "bonett"))) {
 
       ci <- c(NA, NA)
 
@@ -461,7 +461,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
       #--------------------------------------------------------------------
       # Chi square method
-      if (method == "chisq") {
+      if (isTRUE(method == "chisq")) {
 
         df <- length(x) - 1L
 
@@ -491,7 +491,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
 
       #--------------------------------------------------------------------
       # Bonett
-      } else if (method == "bonett") {
+      } else if (isTRUE(method == "bonett")) {
 
         n <- length(x)
 
@@ -531,7 +531,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # No Grouping, No Split
 
-  if (is.null(group) && is.null(split)) {
+  if (isTRUE(is.null(group) && is.null(split))) {
 
     result <- data.frame(variable = colnames(x),
                          n = vapply(x, function(y) length(na.omit(y)), FUN.VALUE = 1L),
@@ -549,7 +549,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Grouping, No Split
 
-  } else if (!is.null(group) && is.null(split)) {
+  } else if (isTRUE(!is.null(group) && is.null(split))) {
 
     object.group <- lapply(split(x, f = group), function(y) misty::ci.sd(y, method = method, alternative = alternative, conf.level = conf.level,
                                                                          group = NULL, split = NULL, sort.var = sort.var, na.omit = na.omit,
@@ -562,7 +562,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # No Grouping, Split
 
-  } else if (is.null(group) && !is.null(split)) {
+  } else if (isTRUE(is.null(group) && !is.null(split))) {
 
       result <- lapply(split(data.frame(x, stringsAsFactors = FALSE), f = split),
                        function(y) misty::ci.sd(y, method = method, alternative = alternative, conf.level = conf.level,
@@ -572,7 +572,7 @@ ci.sd <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided",
   #----------------------------------------
   # Grouping, Split
 
-  } else if (!is.null(group) && !is.null(split)) {
+  } else if (isTRUE(!is.null(group) && !is.null(split))) {
 
     result <- lapply(split(data.frame(x, group = group, stringsAsFactors = FALSE), f = split),
                        function(y) misty::ci.sd(y[, -grep("group", names(y))], method = method,
