@@ -6,7 +6,8 @@
 #'                    factors and character variables are excluded from \code{x} before conducting the analysis.
 #' @param print       a character vector indicating which statistical measures to be printed on the console,
 #'                    i.e. \code{n} (number of observations), \code{nNA} (number of missing values),
-#'                    \code{pNA} (percentage of missing values), \code{m} (arithmetic mean), \code{var} (variance),
+#'                    \code{pNA} (percentage of missing values), \code{m} (arithmetic mean),
+#'                    \code{se.m} (standard error of the arithmetic mean), \code{var} (variance),
 #'                    \code{sd} (standard deviation), \code{med} (median),\code{min} (minimum),
 #'                    \code{p25} (25th percentile, first quartile), \code{p75} (75th percentile, third quartile),
 #'                    \code{max} (maximum),  \code{range} (range), \code{iqr} (interquartile range),
@@ -86,7 +87,7 @@
 #' # Descriptive statistics for x1, x2, and x3,
 #' # analysis by group1 separately, split analysis by group2
 #' descript(dat[, c("x1", "x2", "x3")], group = dat$group1, split = dat$group2)
-descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt"),
+descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "se.m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt"),
                      group = NULL, split = NULL, sort.var = FALSE, na.omit = FALSE,
                      digits = 2, as.na = NULL, check = TRUE, output = TRUE) {
 
@@ -95,7 +96,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #......
   # Check if input 'x' is missing
-  if (missing(x)) {
+  if (isTRUE(missing(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -104,7 +105,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #......
   # Check if input 'x' is NULL
-  if (is.null(x)) {
+  if (isTRUE(is.null(x))) {
 
     stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
 
@@ -112,7 +113,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #......
   # Vector, matrix or data frame for the argument 'x'?
-  if (!is.atomic(x) && !is.matrix(x) && !is.data.frame(x)) {
+  if (isTRUE(!is.atomic(x) && !is.matrix(x) && !is.data.frame(x))) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -122,19 +123,23 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
   #----------------------------------------
   # Data frame
 
+  # Is 'x' a matrix?
+  is.mat <- is.matrix(x) && !is.data.frame(x)
+
+  # Coerce to a data frame
   x <- as.data.frame(x, stringsAsFactors = FALSE)
 
   #----------------------------------------
   # Convert user-missing values into NA
 
-  if (!is.null(as.na)) {
+  if (isTRUE(!is.null(as.na))) {
 
     # Replace user-specified values with missing values
-    x <- misty::as.na(x, as.na = as.na, check = check)
+    x <- misty::as.na(x, na = as.na, check = check)
 
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After converting user-missing values into NA, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -149,14 +154,14 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
   # Non-numeric variables
   non.num <- !vapply(x, is.numeric, FUN.VALUE = logical(1))
 
-  if (any(non.num)) {
+  if (isTRUE(any(non.num))) {
 
     x <- x[, -which(non.num), drop = FALSE]
 
     #......
     # Variables left
 
-    if (ncol(x) == 0L) {
+    if (isTRUE(ncol(x) == 0L)) {
 
       stop("No variables left for analysis after excluding non-numeric variables.", call. = FALSE)
 
@@ -174,7 +179,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # No group and split variable
-    if (is.null(group) && is.null(split)) {
+    if (isTRUE(is.null(group) && is.null(split))) {
 
       x <- na.omit(as.data.frame(x, stringsAsFactors = FALSE))
 
@@ -185,7 +190,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Group variable, no split variable
-    if (!is.null(group) && is.null(split)) {
+    if (isTRUE(!is.null(group) && is.null(split))) {
 
       x.group <- na.omit(data.frame(x, group = group, stringsAsFactors = FALSE))
 
@@ -199,7 +204,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # No group variable, split variable
-    if (is.null(group) && !is.null(split)) {
+    if (isTRUE(is.null(group) && !is.null(split))) {
 
       x.split <- na.omit(data.frame(x, split = split, stringsAsFactors = FALSE))
 
@@ -213,7 +218,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Group variable, split variable
-    if (!is.null(group) && !is.null(split)) {
+    if (isTRUE(!is.null(group) && !is.null(split))) {
 
       x.group.split <- na.omit(data.frame(x, group = group, split = split, stringsAsFactors = FALSE))
 
@@ -229,7 +234,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
     #......
     # Variable with missing values only
     x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L))
-    if (any(x.miss)) {
+    if (isTRUE(any(x.miss))) {
 
       stop(paste0("After listwise deletion, following variables are completely missing: ",
                   paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
@@ -243,7 +248,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #......
   # Check input 'check'
-  if (!is.logical(check)) {
+  if (isTRUE(!is.logical(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -255,50 +260,95 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'print'
-    if (!all(print %in%  c("all", "n", "nNA", "pNA", "m", "var", "sd", "min", "p25", "med", "p75", "max", "skew", "range", "iqr", "kurt"))) {
+    if (isTRUE(!all(print %in%  c("all", "n", "nNA", "pNA", "m", "se.m", "var", "sd", "min", "p25", "med", "p75", "max", "skew", "range", "iqr", "kurt")))) {
 
-      stop("Character strings in the argument 'print' do not all match with \"all\", \"n\", \"nNA\", \"pNA\", \"m\", \"var\", \"sd\", \"min\", \"p25\", \"med\", \"p75\", \"max\", \"range\", \"iqr\", \"skew\", or \"kurt\".",
+      stop("Character strings in the argument 'print' do not all match with \"all\", \"n\", \"nNA\", \"pNA\", \"m\", \"se.m\", \"var\", \"sd\", \"min\", \"p25\", \"med\", \"p75\", \"max\", \"range\", \"iqr\", \"skew\", or \"kurt\".",
            call. = FALSE)
 
     }
 
     #......
     # Check input 'group'
-    if (!is.null(group)) {
+    if (isTRUE(!is.null(group))) {
 
       # Vector or factor for the argument 'group'?
-      if (!is.vector(group) && !is.factor(group)) {
+      if (isTRUE(!is.vector(group) && !is.factor(group))) {
 
         stop("Please specify a vector or factor for the argument 'group'.", call. = FALSE)
 
       }
 
       # Length of 'group' match with 'x'?
-      if (length(group) != nrow(x)) {
+      if (isTRUE(length(group) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
+
+          # Vector
+          if (isTRUE(is.vector(group) && !is.factor(group))) {
+
+            stop("Length of the vector specified in 'group' does not match the length of the vector in 'x'.",
+                 call. = FALSE)
+
+          # Factor
+          } else {
+
+            stop("Length of the factor specified in 'group' does not match the length of the vector in 'x'.",
+                 call. = FALSE)
+
+          }
 
-          stop("Length of the vector or factor specified in 'group' does not match the length of the vector in 'x'.",
-               call. = FALSE)
 
         } else {
 
-          stop("Length of the vector or factor specified in 'group' does not match the number of rows of the matrix or data frame in 'x'.",
-               call. = FALSE)
+          # Vector
+          if (isTRUE(is.vector(group) && !is.factor(group))) {
+
+            # Matrix
+            if (isTRUE(is.mat)) {
+
+              stop("Length of the vector specified in 'group' does not match the number of rows of the matrix in 'x'.",
+                   call. = FALSE)
+
+            # Data frame
+            } else {
+
+              stop("Length of the vector specified in 'group' does not match the number of rows of the data frame in 'x'.",
+                   call. = FALSE)
+
+            }
+
+          # Factor
+          } else {
+
+            # Matrix
+            if (isTRUE(is.mat)) {
+
+              stop("Length of the factor specified in 'group' does not match the number of rows of the matrix in 'x'.",
+                   call. = FALSE)
+
+            # Data frame
+            } else {
+
+              stop("Length of the factor specified in 'group' does not match the number of rows of the data frame in 'x'.",
+                   call. = FALSE)
+
+            }
+
+          }
 
         }
 
       }
 
       # Input 'group' completely missing
-      if (all(is.na(group))) {
+      if (isTRUE(all(is.na(group)))) {
 
         stop("The grouping variable specified in 'group' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'group'
-      if (length(na.omit(unique(group))) == 1L) {
+      if (isTRUE(length(na.omit(unique(group))) == 1L)) {
 
         warning("There is only one group represented in the grouping variable specified in 'group'.", call. = FALSE)
 
@@ -308,41 +358,85 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'split'
-    if (!is.null(split)) {
+    if (isTRUE(!is.null(split))) {
 
       # Vector or factor for the argument 'split'?
-      if (!is.vector(split) && !is.factor(split)) {
+      if (isTRUE(!is.vector(split) && !is.factor(split))) {
 
         stop("Please specify a vector or factor for the argument 'split'.", call. = FALSE)
 
       }
 
-      # Length of 'split' doest not match with 'x'
-      if (length(split) != nrow(x)) {
+      # Length of 'split' does not match with 'x'
+      if (isTRUE(length(split) != nrow(x))) {
 
-        if (ncol(x) == 1L) {
+        if (isTRUE(ncol(x) == 1L)) {
 
-          stop("Length of the vector or factor specified in 'split' does not match the length of the vector in 'x'.",
-               call. = FALSE)
+          # Vector
+          if (is.vector(split) && !is.factor(split)) {
+
+            stop("Length of the vector specified in 'split' does not match the length of the vector in 'x'.",
+                 call. = FALSE)
+
+          # Factor
+          } else {
+
+            stop("Length of the factor specified in 'split' does not match length of the vector in 'x'.",
+                 call. = FALSE)
+
+          }
 
         } else {
 
-          stop("Length of the vector or factor specified in 'split' does not match the number of rows of the matrix or data frame in 'x'.",
-               call. = FALSE)
+          # Vector
+          if (isTRUE(is.vector(split) && !is.factor(split))) {
+
+            # Matrix
+            if (isTRUE(is.mat)) {
+
+              stop("Length of the vector specified in 'split' does not match the number of rows of the matrix in 'x'.",
+                   call. = FALSE)
+
+            # Data frame
+            } else {
+
+              stop("Length of the vector specified in 'split' does not match the number of rows of the data frame in 'x'.",
+                   call. = FALSE)
+
+            }
+
+          # Factor
+          } else {
+
+            # Matrix
+            if (isTRUE(is.mat)) {
+
+              stop("Length of the factor specified in 'split' does not match the number of rows of the matrix in 'x'.",
+                   call. = FALSE)
+
+            # Data frame
+            } else {
+
+              stop("Length of the factor specified in 'split' does not match the number of rows of the data frame in 'x'.",
+                   call. = FALSE)
+
+            }
+
+          }
 
         }
 
       }
 
       # Input 'split' completely missing
-      if (all(is.na(split))) {
+      if (isTRUE(all(is.na(split)))) {
 
         stop("The split variable specified in 'split' is completely missing.", call. = FALSE)
 
       }
 
       # Only one group in 'split'
-      if (length(na.omit(unique(split))) == 1L) {
+      if (isTRUE(length(na.omit(unique(split))) == 1L)) {
 
         warning("There is only one group represented in the split variable specified in 'split'.", call. = FALSE)
 
@@ -352,7 +446,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'sort.var'
-    if (!is.logical(sort.var)) {
+    if (isTRUE(!is.logical(sort.var))) {
 
       stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE)
 
@@ -360,7 +454,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'na.omit'
-    if (!is.logical(na.omit)) {
+    if (isTRUE(!is.logical(na.omit))) {
 
       stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
 
@@ -368,7 +462,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'digits'
-    if (digits %% 1L != 0L || digits < 0L) {
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
 
       stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE)
 
@@ -376,7 +470,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
     #......
     # Check input 'output'
-    if (!is.logical(output)) {
+    if (isTRUE(!is.logical(output))) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
@@ -390,15 +484,15 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
   #----------------------------------------
   # Statistical measures
 
-  if (all(c("all", "n", "nNA", "pNA", "m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt") %in% print)) {
+  if (isTRUE(all(c("all", "n", "nNA", "pNA", "m", "se.m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt") %in% print))) {
 
     print <- c("n", "nNA", "pNA", "m", "sd", "min", "max", "skew", "kurt")
 
   }
 
-  if (length(print) == 1L && print == "all") {
+  if (isTRUE(length(print) == 1L && print == "all")) {
 
-    print <- c("n", "nNA", "pNA", "m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt")
+    print <- c("n", "nNA", "pNA", "m", "se.m", "var", "sd", "min", "p25", "med", "p75", "max", "range", "iqr", "skew", "kurt")
 
   }
 
@@ -408,13 +502,14 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
   #----------------------------------------
   # No Grouping, No Split
 
-  if (is.null(group) && is.null(split)) {
+  if (isTRUE(is.null(group) && is.null(split))) {
 
     result <- data.frame(variable = colnames(x),
                          n = vapply(x, function(y) length(na.omit(y)), FUN.VALUE = 1L),
                          nNA = vapply(x, function(y) sum(is.na(y)), FUN.VALUE = 1L),
                          pNA = vapply(x, function(y) sum(is.na(y)) / length(y) * 100L, FUN.VALUE = double(1)),
                          m = vapply(x, function(y) ifelse(length(na.omit(y)) <= 1L, NA, mean(y, na.rm = TRUE)), FUN.VALUE = double(1L)),
+                         se.m = vapply(x, function(y) ifelse(length(na.omit(y)) <= 1L, NA, sd(y, na.rm = TRUE) / sqrt(length(na.omit(y)))), FUN.VALUE = double(1L)),
                          var = vapply(x, function(y) ifelse(length(na.omit(y)) <= 1L, NA, var(y, na.rm = TRUE)), FUN.VALUE = double(1L)),
                          sd = vapply(x, function(y) ifelse(length(na.omit(y)) <= 1L, NA, sd(y, na.rm = TRUE)), FUN.VALUE = double(1L)),
                          min = vapply(x, function(y) ifelse(length(na.omit(y)) <= 1L, NA, min(y, na.rm = TRUE)), FUN.VALUE = double(1L)),
@@ -430,7 +525,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #----------------------------------------
   # Grouping, No Split
-  } else if (!is.null(group) && is.null(split)) {
+  } else if (isTRUE(!is.null(group) && is.null(split))) {
 
     object.group <- lapply(split(x, f = group), function(y) misty::descript(y, group = NULL, split = NULL, sort.var = sort.var, na.omit = na.omit,
                                                                             as.na = as.na, check = FALSE, output = FALSE)$result)
@@ -441,7 +536,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #----------------------------------------
   # No Grouping, Split
-  } else if (is.null(group) && !is.null(split)) {
+  } else if (isTRUE(is.null(group) && !is.null(split))) {
 
     result <- lapply(split(data.frame(x, stringsAsFactors = FALSE), f = split),
                      function(y) misty::descript(y, group = NULL, split = NULL, sort.var = sort.var,
@@ -450,7 +545,7 @@ descript <- function(x, print = c("all", "n", "nNA", "pNA", "m", "var", "sd", "m
 
   #----------------------------------------
   # Grouping, Split
-  } else if (!is.null(group) && !is.null(split)) {
+  } else if (isTRUE(!is.null(group) && !is.null(split))) {
 
     result <- lapply(split(data.frame(x, group = group, stringsAsFactors = FALSE), f = split),
                      function(y) misty::descript(y[, -grep("group", names(y))], group = y$group, split = NULL,
